pub struct CmdLine {
name: String,
contents: Vec<String>,
}Expand description
A CmdLine holds a set of command-line arguments that augment a configuration.
These arguments are formatted in toml, and concatenated into a single toml object. With arguments of the form “key=bareword”, the bareword is quoted for convenience.
Fields
name: StringString for decorating Values.
contents: Vec<String>List of toml lines as given on the command line.
Implementations
Sourceimpl CmdLine
impl CmdLine
Sourcepub fn push_toml_line(&mut self, line: String)
pub fn push_toml_line(&mut self, line: String)
Add a single line of toml to the configuration.
Sourcefn convert_toml_error(
&self,
toml_str: &str,
error_message: &str,
span: &Option<Range<usize>>,
) -> String
fn convert_toml_error( &self, toml_str: &str, error_message: &str, span: &Option<Range<usize>>, ) -> String
Try to adjust the contents of a toml deserialization error so that instead it refers to a single command-line argument.
Sourcefn build_toml(&self) -> String
fn build_toml(&self) -> String
Compose elements of this cmdline into a single toml string.