macro_rules! should_not_be_used_in_collection {
{ $($t:ty),* $(,)?} => { ... };
}Expand description
Declare that types shouldn’t be used in a collection (because they would want magic serde handling, but that isn’t implemented).
macro_rules! should_not_be_used_in_collection {
{ $($t:ty),* $(,)?} => { ... };
}Declare that types shouldn’t be used in a collection (because they would want magic serde handling, but that isn’t implemented).