ShouldBeCaughtAsSerdeSpecialCase

Trait ShouldBeCaughtAsSerdeSpecialCase 

pub trait ShouldBeCaughtAsSerdeSpecialCase: SealSerdeSpecialCase { }
A trait implemented by all the types that should receive automatic serde magic handling.

We use this trait to detect cases that the tor_config derive macro should have caught, but didn’t– probably because the type was an alias.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ShouldBeCaughtAsSerdeSpecialCase for Duration

Implementors