ShouldBeCaughtAsSpecialCase

Trait ShouldBeCaughtAsSpecialCase 

pub trait ShouldBeCaughtAsSpecialCase: SealSpecialCase { }
A trait implemented by all the types that normalize_and_invoke does anything magic for.

We use this trait to detect cases that normalize_and_invoke should have handled, but didn’t– probably because the type was an alias.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ShouldBeCaughtAsSpecialCase for NonZero<u8>

Source

impl ShouldBeCaughtAsSpecialCase for NonZero<u16>

Source

impl ShouldBeCaughtAsSpecialCase for NonZero<u32>

Source

impl ShouldBeCaughtAsSpecialCase for NonZero<u64>

Source

impl ShouldBeCaughtAsSpecialCase for NonZero<u128>

Source

impl ShouldBeCaughtAsSpecialCase for String

Source

impl<T> ShouldBeCaughtAsSpecialCase for Option<T>

Implementors