pub trait ShouldUseListBuilder: SealUseListBuilder {
type Element;
}Expand description
A trait implemented by the types for which we should recommend the use of a list builder.
pub trait ShouldUseListBuilder: SealUseListBuilder {
type Element;
}A trait implemented by the types for which we should recommend the use of a list builder.