#[non_exhaustive]
pub enum ReconfigureError {
    CannotChange {
        field: String,
    },
    UnsupportedSituation(String),
    Bug(Bug),
}
An error caused when attempting to reconfigure an existing Arti client, or one of its modules.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


CannotChange

Fields

field: String

The field (or fields) that we tried to change.

Tried to change a field that cannot change on a running client.



UnsupportedSituation(String)

The requested configuration is not supported in this situation

Something, probably discovered at runtime, is not compatible with the specified configuration.

This ought not to be returned when the configuration is simply not supported by this build of arti - that should be reported at config build type as ConfigBuildError::Unsupported.



Bug(Bug)

There was a programming error somewhere in our code, or the calling code.