#[non_exhaustive]pub enum ConfigError {
FileAccess(Error),
Permissions(Error),
Load(ConfigLoadError),
Io {
action: &'static str,
path: PathBuf,
err: Arc<Error>,
},
}Expand description
An error that occurs while trying to read and process our configuration.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
FileAccess(Error)
We encoundered a problem checking file permissions (for example, no such file)
Permissions(Error)
use ConfigError::FileAccess instead
We encoundered a problem checking file permissions (for example, no such file)
This variant name is misleading - see the docs for fs_mistrust::Error.
Please use ConfigError::FileAccess instead.
Load(ConfigLoadError)
Our underlying configuration library gave an error while loading our configuration.
Io
Encountered an IO error with a configuration file or directory.
Note that some IO errors may be reported as Load errors,
due to limitations of the underlying library.
Implementations
Sourceimpl ConfigError
impl ConfigError
Sourcepub(crate) fn from_cfg_err(err: Error) -> Self
pub(crate) fn from_cfg_err(err: Error) -> Self
Wrap err as a ConfigError.
This is not a From implementation, since we don’t want to expose our underlying configuration library.