enum DirEventFilter {
MatchesExtension(String),
MatchesPath(PathBuf),
}Expand description
A filter for deciding what to do with a notify::Event pertaining to files that are relative to one of the directories we are watching.
Variants
MatchesExtension(String)
Notify the caller about the event, if the file has the specified extension.
MatchesPath(PathBuf)
Notify the caller about the event, if the file has the specified path.
Implementations
Sourceimpl DirEventFilter
impl DirEventFilter
Sourcefn accepts_path(&self, path: &Path) -> bool
fn accepts_path(&self, path: &Path) -> bool
Check whether this filter accepts path.