macro_rules! call_any {
{ $what:ident $( $args:tt )* } => { ... };
}Expand description
Implement deserialize_$what as a call to deserialize_any.
$args, if provided, are any other formal arguments, not including the Visitor
macro_rules! call_any {
{ $what:ident $( $args:tt )* } => { ... };
}Implement deserialize_$what as a call to deserialize_any.
$args, if provided, are any other formal arguments, not including the Visitor