struct FieldExtractor;Expand description
Stunt “data format” which we use for extracting fields for derived Flattenable impls
The field extraction works as follows:
- We ask serde to deserialize
$ttypefrom aFieldExtractor - We expect the serde-macro-generated
Deserializeimpl to calldeserialize_struct - We return the list of fields to match up as an error