pub struct VecBuilder<T>where
T: Clone,{
values: Option<Vec<T>>,
}Expand description
List of T, a straightforward type, being built as part of the configuration
The default is the empty list.
Example
use derive_builder::Builder;
use serde::{Deserialize, Serialize};
use tor_config::ConfigBuildError;
use tor_config::{define_list_builder_accessors, list_builder::VecBuilder};
use std::net::SocketAddr;
#[derive(Debug, Clone, Builder)]
#[builder(build_fn(error = "ConfigBuildError"))]
#[builder(derive(Debug, Serialize, Deserialize))]
pub struct FallbackDir {
#[builder(sub_builder(fn_name = "build"), setter(custom))]
orports: Vec<SocketAddr>,
}
define_list_builder_accessors! {
struct FallbackDirBuilder {
pub orports: [SocketAddr],
}
}
let mut bld = FallbackDirBuilder::default();
bld.orports().push("[2001:db8:0::42]:12".parse().unwrap());
assert_eq!( bld.build().unwrap().orports[0].to_string(),
"[2001:db8::42]:12" );Wrapper struct to help derive_builder find the right types and methods
This struct is not part of the configuration API. Refer to the containing structures for information on how to build the config.
Fields
values: Option<Vec<T>>The list, as overridden
Implementations
Sourceimpl<T> VecBuilder<T>where
T: Clone,
impl<T> VecBuilder<T>where
T: Clone,
Sourcepub fn build(&self) -> Result<Vec<T>, ConfigBuildError>
pub fn build(&self) -> Result<Vec<T>, ConfigBuildError>
Resolve this list to a list of built items.
If the value is still the Default,
a built-in default list will be built and returned;
otherwise each applicable item will be built,
and the results collected into a single built list.
Sourcefn default_list() -> Vec<T>
fn default_list() -> Vec<T>
The default list
Sourcepub fn access(&mut self) -> &mut Vec<T>
pub fn access(&mut self) -> &mut Vec<T>
Resolve the list to the default if necessary and then return &mut Vec
Sourcepub fn access_opt(&self) -> &Option<Vec<T>>
pub fn access_opt(&self) -> &Option<Vec<T>>
Resolve the list to the default if necessary and then return &mut Vec
Sourcepub fn access_opt_mut(&mut self) -> &mut Option<Vec<T>>
pub fn access_opt_mut(&mut self) -> &mut Option<Vec<T>>
Resolve the list to the default if necessary and then return &mut Vec