enum CustomizableListen {
Disabled,
One(ListenItem),
List(Vec<ListenItem>),
}Expand description
A general structure for configuring listening ports.
This is meant to provide some basic parsing without being too opinionated.
If you have further requirements, you should wrap this in a new type.
For example if CustomizableListen supports keywords or flags in the future such as “auto”,
any config options that don’t want to support them should use a wrapper type that handles them
and returns an error.
Variants
Disabled
Explicitly disabled with false.
One(ListenItem)
A single item not in a list.
List(Vec<ListenItem>)
A list of items.
Implementations
Sourceimpl CustomizableListen
impl CustomizableListen
Sourcefn items(&self) -> impl Iterator<Item = &ListenItem>
fn items(&self) -> impl Iterator<Item = &ListenItem>
All configured listen options.