ListenItem

Enum ListenItem 

enum ListenItem {
    Port(u16),
    Auto,
    AutoPort(IpAddr),
    General(SocketAddr),
}
One item in the CustomizableListen.

This type defines a common format for parsing. We don’t assign any particular meaning to the variants. For example a standalone port doesn’t imply anything about what IP address should be used. Similarly, a port of 0 doesn’t have any inherent meaning. For example a port of 0 might mean “don’t listen” (when network addresses are optional) or might mean “raise an error” (when network addresses are required). It’s up to the user of this type to assign meaning to the values given.

We distinguish a standalone port, rather than just storing two net:SocketAddr, so that we can handle localhost (which means two address families) specially in order to implement localhost_port_legacy().

Variants



Port(u16)

One port, both IPv6 and IPv4



Auto

IPv6 and/or IPv4, arbitrarily chosen ports.



AutoPort(IpAddr)

Specific address, arbitrarily chosen port.



General(SocketAddr)

Any other single socket address

Implementations

Source

impl ListenItem

fn iter<'a>( &'a self, ips_for_port: impl IntoIterator<Item = IpAddr> + 'a, ) -> impl Iterator<Item = SocketAddr> + 'a

Return the SocketAddrs implied by this item

If the item is a standalone port, then the returned iterator will return a socket address using that port for each IP address in ips_for_port.

fn is_auto(&self) -> bool

Return true if this ListenItem is “addr:auto” or “auto”

fn is_port_zero(&self) -> bool

Return true if this ListenItem is using an explicit (deprecated) port value of 0.