pub struct ResolveContext<'a> {
input: &'a ConfigurationTree,
unrecognized: UnrecognizedKeys,
output_tree: Option<ConfigurationTree>,
}Expand description
Config resolution context, not used outside tor_config::load
This is public only because it appears in the Resolvable trait.
You don’t want to try to obtain one.
Fields
input: &'a ConfigurationTreeThe input
unrecognized: UnrecognizedKeysPaths unrecognized by all deserializations
None means we haven’t deserialized anything yet, ie means the universal set.
Empty is used to disable this feature.
output_tree: Option<ConfigurationTree>If present, a ConfigurationTree to receive all recognized or defaulted
settings from the input tree.