macro_rules! assert_config_error {
($err:expr, $kind:tt, $expect_problem:expr) => { ... };
}Expand description
Assert that the specified error is the specified kind of
ConfigBuildError.
macro_rules! assert_config_error {
($err:expr, $kind:tt, $expect_problem:expr) => { ... };
}Assert that the specified error is the specified kind of
ConfigBuildError.