macro_rules! derive_deftly_template_TorConfig {
({ $($driver:tt)* } [$($aoptions:tt)*] ($($future:tt)*) $($tpassthrough:tt)*) => { ... };
($($wrong:tt)*) => { ... };
}Expand description
Define a builder type for a given type, with settings appropriate to participate in the Arti build system.
See module documentation for more information and usage instructions.
This is a derive_deftly template. Do not invoke it directly.
To use it, write: #[derive(Deftly)] #[derive_deftly(TorConfig)].