MetricsConfigBuilder

Struct MetricsConfigBuilder 

pub struct MetricsConfigBuilder {
    prometheus: PrometheusConfigBuilder,
}
A builder to create an instance of MetricsConfig.

Fields

prometheus: PrometheusConfigBuilder

In-progress value for prometheus.

See MetricsConfig.prometheus

Implementations

Source

impl MetricsConfigBuilder

pub fn prometheus(&mut self) -> &mut PrometheusConfigBuilder

Return a mutable reference to the inner builder for prometheus.

prometheus

Where to listen for incoming HTTP connections.

Source

impl MetricsConfigBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<MetricsConfig, ConfigBuildError>

Try to construct a new MetricsConfig from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.