pub struct ConfigurationTree(/* private fields */);Expand description
A set of configuration fields, represented as a set of nested K=V mappings.
(This is a wrapper for an underlying type provided by the library that actually does our configuration.)
Implementations
Sourceimpl ConfigurationTree
impl ConfigurationTree
Sourcepub fn get_serde_value<T: DeserializeOwned>(
&self,
key: &str,
) -> Result<Option<T>, ConfigGetValueError>
pub fn get_serde_value<T: DeserializeOwned>( &self, key: &str, ) -> Result<Option<T>, ConfigGetValueError>
Return the value with a given key as some type that implements Deserialize.
Return None if no such value is set in this tree.
Sourcepub fn merge_from<T>(&mut self, config: &T) -> Result<(), ConfigError>where
T: Serialize,
pub fn merge_from<T>(&mut self, config: &T) -> Result<(), ConfigError>where
T: Serialize,
Override our current tree with the settings in config.
config must be implement Serialize,
and must serialize to a map.
This operation follows the same as are used when reading multiple configuration files in sequence, where option settings in later files replace earlier ones.