pub trait NotAutoValue { }Expand description
A marker trait for types that do not serialize to the same value as ExplicitOrAuto::Auto.
Important: you should not implement this trait manually.
Use the impl_not_auto_value macro instead.
This trait should be implemented for types that can be stored in ExplicitOrAuto.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".