pub trait ShouldBeCaughtAsSerdeSpecialCase: SealSerdeSpecialCase { }Expand description
A trait implemented by all the types that should receive automatic serde magic handling.
We use this trait to detect cases that the tor_config derive macro should have caught, but didn’t– probably because the type was an alias.