pub trait ShouldBeCaughtAsSpecialCase: SealSpecialCase { }Expand description
A trait implemented by all the types that normalize_and_invoke does anything magic for.
We use this trait to detect cases that normalize_and_invoke should have handled, but didn’t– probably because the type was an alias.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".