ShouldUseListBuilder

Trait ShouldUseListBuilder 

pub trait ShouldUseListBuilder: SealUseListBuilder {
    type Element;
}
A trait implemented by the types for which we should recommend the use of a list builder.

Required Associated Types

type Element

The element type of this list.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> ShouldUseListBuilder for BTreeSet<T>

Source

impl<T> ShouldUseListBuilder for HashSet<T>

Source

impl<T> ShouldUseListBuilder for Vec<T>

Implementors