pub trait ShouldUseListBuilder: SealUseListBuilder {
type Element;
}Expand description
A trait implemented by the types for which we should recommend the use of a list builder.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".