ShouldUseListBuilder

Trait ShouldUseListBuilder 

pub trait ShouldUseListBuilder: SealUseListBuilder {
    type Element;
}
A trait implemented by the types for which we should recommend the use of a list builder.

Required Associated Types

type Element

The element type of this list.

Implementations on Foreign Types

Source

impl<T> ShouldUseListBuilder for BTreeSet<T>

Source

impl<T> ShouldUseListBuilder for Vec<T>

Source

impl<T> ShouldUseListBuilder for HashSet<T>

Implementors