ShouldUseMapBuilder

Trait ShouldUseMapBuilder 

pub trait ShouldUseMapBuilder: SealUseMapBuilder {
    type BuilderMap;
}
A trait implemented by the types for which we should recommend the use of a map builder.

Required Associated Types

type BuilderMap

The corresponding type to use inside this map builder

Implementations on Foreign Types

Source

impl<T> ShouldUseMapBuilder for BTreeMap<String, T>
where T: Buildable,

Source

impl<T> ShouldUseMapBuilder for HashMap<String, T>
where T: Buildable,

Implementors