pub trait ShouldUseMapBuilder: SealUseMapBuilder {
type BuilderMap;
}Expand description
A trait implemented by the types for which we should recommend the use of a map builder.
Required Associated Types
Sourcetype BuilderMap
type BuilderMap
The corresponding type to use inside this map builder