macro_rules! call_any_for_rest {
{} => { ... };
}Expand description
Implement most deserialize_* as calls to deserialize_any.
The exceptions are the ones we need to handle specially in any of our types,
namely any itself and struct.
macro_rules! call_any_for_rest {
{} => { ... };
}Implement most deserialize_* as calls to deserialize_any.
The exceptions are the ones we need to handle specially in any of our types,
namely any itself and struct.