#[non_exhaustive]pub struct ConfigResolveOptions {
pub want_output_tree: bool,
/* private fields */
}Expand description
A set of options to use for resolving a configuration tree.
These options should not affect the actual configuration objects returned
by resolve_return_results, though they may affect other elements
of ResolutionResults.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.want_output_tree: boolIf true, we should return an output_tree value containing the all the settings that we used to build the configuration, including the default values for any settings that were not present in the input.