ResolveContext

Struct ResolveContext 

pub struct ResolveContext {
    input: ConfigurationTree,
    unrecognized: UnrecognizedKeys,
}
Config resolution context, not used outside tor_config::load

This is public only because it appears in the Resolvable trait. You don’t want to try to obtain one.

Fields

input: ConfigurationTree

The input

unrecognized: UnrecognizedKeys

Paths unrecognized by all deserializations

None means we haven’t deserialized anything yet, ie means the universal set.

Empty is used to disable this feature.