pub struct PrometheusConfigBuilder { /* private fields */ }Expand description
A builder to create an instance of PrometheusConfig.
Implementations
Sourceimpl PrometheusConfigBuilder
impl PrometheusConfigBuilder
Sourcepub fn listen(&mut self, val: Listen) -> &mut Self
pub fn listen(&mut self, val: Listen) -> &mut Self
Provide a value for listen.
If no value is provided for listen, build will use Default::default().
listen
Port on which to establish a Prometheus scrape endpoint
We listen here for incoming HTTP connections.
If just a port is provided, we don’t support IPv6. Alternatively, (only) a single address and port can be specified. These restrictions are due to upstream limitations: https://github.com/metrics-rs/metrics/issues/567.
Sourceimpl PrometheusConfigBuilder
impl PrometheusConfigBuilder
Sourcepub fn build(&self) -> Result<PrometheusConfig, ConfigBuildError>
pub fn build(&self) -> Result<PrometheusConfig, ConfigBuildError>
Try to construct a new PrometheusConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.